@@ -30,6 +30,7 @@ from .flaskutils import current_user
 from .flaskutils import permissions_needed
 from .flaskutils import smtp_needed
 from .flaskutils import user_needed
+from .forms import FirstLoginForm
 from .forms import ForgottenPasswordForm
 from .forms import InvitationForm
 from .forms import LoginForm
@@ -147,7 +148,7 @@ def firstlogin(uid):
     if not user or user.has_password():
         abort(404)
 
-    form = ForgottenPasswordForm(request.form or None, data={"login": uid})
+    form = FirstLoginForm(request.form or None)
     if not request.form:
         return render_template("firstlogin.html", form=form, uid=uid)
 
@@ -381,9 +382,11 @@ def profile_create(current_app, form):
         for group in groups:
             group.add_member(user)
 
-    if not form["password1"].data or user.set_password(form["password1"].data):
-        flash(_("User account creation succeed."), "success")
-        user.save()
+    if form["password1"].data:
+        user.set_password(form["password1"].data)
+
+    flash(_("User account creation succeed."), "success")
+    user.save()
 
     return user
 
@@ -490,11 +493,11 @@ def profile_edit(editor, username):
                 user["jpegPhoto"] = None
 
             if (
-                "password1" not in request.form
-                or not form["password1"].data
-                or user.set_password(form["password1"].data)
-            ) and request.form["action"] == "edit":
-                flash(_("Profile updated successfuly."), "success")
+                "password1" in request.form
+                and form["password1"].data
+                and request.form["action"] == "edit"
+            ):
+                user.set_password(form["password1"].data)
 
             if (
                 "preferredLanguage" in request.form
@@ -502,6 +505,7 @@ def profile_edit(editor, username):
             ):
                 user.preferredLanguage = None
 
+            flash(_("Profile updated successfuly."), "success")
             user.save()
             return redirect(url_for("account.profile_edition", username=username))
 
@@ -624,6 +628,12 @@ def photo(uid, field):
         abort(404)
 
     user = User.get(uid)
-    photo = getattr(user, field)[0]
-    stream = io.BytesIO(photo)
+    if not user:
+        abort(404)
+
+    photos = getattr(user, field)
+    if not photos:
+        abort(404)
+
+    stream = io.BytesIO(photos[0])
     return send_file(stream, mimetype="image/jpeg")
